@@ -38,9 +38,7 @@
 #include <KHelpClient>
 #include <KMessageBox>
 #include <KIO/CommandLauncherJob>
-#include <KToolInvocation>
 #include <KShell>
-#include <KStatusNotifierItem>
 #include <KLocalizedString>
 
 #include <QApplication>
